@@ -3,8 +3,6 @@ package RTx::RightsMatrix;
 use strict;
 use Data::Dumper;
 use Storable;
-use RTx::RightsMatrix::Util;
-use RTx::RightsMatrix::RolePrincipal;
 
 =head1 NAME
 
@@ -27,7 +25,7 @@ L<svn://svn.chaka.net/RTx-RightsMatrix>
 
 =cut
 
-our $VERSION = '0.03.00';
+our $VERSION = '0.01';
 
 {
     no warnings qw(redefine);
